#ifndef SOURCELINE_H
#define SOURCELINE_H

#include "Line.h"

/**
 * SourceLine interface
 */
class SourceLine : public Line
{
public:
	SourceLine() { }
	~SourceLine() { }
	virtual DEV_ERR_CODE Open() = 0;
	virtual DEV_ERR_CODE Close() = 0;
	virtual DEV_ERR_CODE Start() = 0;
	virtual DEV_ERR_CODE Stop() = 0;
	virtual DEV_ERR_CODE Read(char bytes[], uint32 numBytes, bool8 isSigned, uint32 *numRead) = 0;
	virtual DEV_ERR_CODE GetNumBytesReadable(uint32 *numReadable) = 0;
	virtual DEV_ERR_CODE GetNumBytesBuffer(uint32 *numBytes) = 0;
	virtual bool8 IsOpen() = 0;
	virtual bool8 IsStarted() = 0;
	virtual uint32 GetSampleRateHz() = 0;
	virtual uint32 GetNumChannels() = 0;
	virtual uint32 GetNumBytesPerSample() = 0;
	virtual void GetName(char name[], uint32 numChars, uint32 *numCharsRequired) = 0;
	
	/**
	 * Forward to num readable function
	 */
	DEV_ERR_CODE GetNumReadWrite(uint32 *numReadWrite)
	{
		return this->GetNumBytesReadable(numReadWrite);
	}

	/**
	 * Forward to read function
	 */
	DEV_ERR_CODE ReadWrite(char bytes[], uint32 numBytes, bool8 isSigned, uint32 *numReadWrite)
	{
		return this->Read(bytes, numBytes, isSigned, numReadWrite);
	}

	/**
	 * Return source line identifier
	 */
	LineType GetType()
	{
		return SOURCE_LINE;
	}

};

#endif